@@ -1,6 +1,9 @@
+from __future__ import absolute_import
+
 from django.http import HttpResponse
 
-from _internalredirect import _convert_file_to_url
+from ._internalredirect import _convert_file_to_url
+
 
 def sendfile(request, filename, **kwargs):
     response = HttpResponse()
@@ -11,4 +14,3 @@ def sendfile(request, filename, **kwargs):
     request.get_host = lambda: ''
 
     return response
-
